// Copyright 2009 the Sputnik authors.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/**
 * Expression in "while" IterationStatement is bracketed with braces
 *
 * @path ch12/12.6/12.6.2/S12.6.2_A6_T2.js
 * @description Checking if execution of "while 0 break" fails
 * @negative
 */

//////////////////////////////////////////////////////////////////////////////
//CHECK#1
while 0 break;
//
//////////////////////////////////////////////////////////////////////////////

